@@ -99,6 +99,10 @@ def main(argv=None):
         "-d", "--csv-delimiter", action="store", default=";", help="a delimiter used in the csv file. Default: \";\""
     )
 
+    input_group.add_argument(
+        "--no-scan", action="store_true", default=False, help="don't do scanning. Just an update."
+    )
+
     output_group = parser.add_argument_group("Output")
     output_group.add_argument(
         "-q",
@@ -285,6 +289,11 @@ def main(argv=None):
 
     cvedb_orig.remove_cache_backup()
 
+    if args["no_scan"]:
+        if not args["quiet"]:
+            LOGGER.info("No scan is selected. Gracefully shutting down.")
+        return 0
+
     # Input validation
     if (
         not args["package_list"]
